DefaultStyle

Struct DefaultStyle 

pub struct DefaultStyle(/* private fields */);
W Default Menu! style.

Implementations

Source

impl DefaultStyle

pub fn panel_fn(&self, panel: impl IntoVar<WidgetFn<PanelArgs>>)

P Widget function that generates the menu layout.

This property can be set in any widget to affect all Menu! descendants.

This property sets PANEL_FN_VAR.

Source

impl DefaultStyle

pub fn has_open(&self, state: impl IntoVar<bool>)

P Gets if any descendant sub-menu is open.

Source

impl DefaultStyle

pub fn widget_new() -> Self

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Methods from Deref<Target = Style>

pub fn widget_build(&mut self) -> StyleBuilder

Build the style.

pub fn replace(&self, replace: impl IntoValue<bool>)

B Fully replace the contextual style.

This is not enabled by default, if set to true the contextual style properties are removed.

pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)

B Set in the default properties of a named style to define the contextual variable for that style.

During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.

This property is part of the named styles pattern, see impl_named_style_fn! for more details.

Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if set in the default properties of a style type.