DefaultStyle

Struct DefaultStyle 

pub struct DefaultStyle(/* private fields */);
W Style applied to SubMenu! not inside any other sub-menus.

Implementations

Source

impl DefaultStyle

pub fn start_column_width(&self, width: impl IntoVar<Length>)

P Width of the icon/checkmark column.

This property sets START_COLUMN_WIDTH_VAR.

Source

impl DefaultStyle

pub fn end_column_width(&self, width: impl IntoVar<Length>)

P Width of the sub-menu expand symbol column.

This property sets END_COLUMN_WIDTH_VAR.

Source

impl DefaultStyle

pub fn is_open(&self, state: impl IntoVar<bool>)

P If the sub-menu popup is open or opening.

Source

impl DefaultStyle

pub fn hover_open_delay(&self, delay: impl IntoVar<Duration>)

P Delay a sub-menu must be hovered to open the popup.

Is 300.ms() by default.

This property sets the HOVER_OPEN_DELAY_VAR.

Source

impl DefaultStyle

pub fn widget_new() -> Self

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Methods from Deref<Target = Style>

pub fn widget_build(&mut self) -> StyleBuilder

Build the style.

pub fn replace(&self, replace: impl IntoValue<bool>)

B Fully replace the contextual style.

This is not enabled by default, if set to true the contextual style properties are removed.

pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)

B Set in the default properties of a named style to define the contextual variable for that style.

During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.

This property is part of the named styles pattern, see impl_named_style_fn! for more details.

Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if set in the default properties of a style type.