pub struct DefaultStyle(/* private fields */);Expand description
W Sub-menu popup default style.
Implementations
Sourceimpl DefaultStyle
impl DefaultStyle
Sourceimpl DefaultStyle
impl DefaultStyle
Sourcepub fn widget_new() -> Self
pub fn widget_new() -> Self
Start building a new instance.
Sourcepub fn widget_type() -> WidgetType
pub fn widget_type() -> WidgetType
Gets the widget type info.
Methods from Deref<Target = DefaultStyle>
Sourcepub fn close_delay(&self, delay: impl IntoVar<Duration>)
pub fn close_delay(&self, delay: impl IntoVar<Duration>)
P Delay awaited before actually closing when popup close is requested.
You can use this delay to await a closing animation for example. This property sets is_close_delaying
while awaiting the delay.
Sourcepub fn is_close_delaying(&self, state: impl IntoVar<bool>)
pub fn is_close_delaying(&self, state: impl IntoVar<bool>)
P If close was requested for this layered widget and it is just awaiting for the close_delay.
Methods from Deref<Target = Style>
Sourcepub fn replace(&self, replace: impl IntoValue<bool>)
pub fn replace(&self, replace: impl IntoValue<bool>)
B Fully replace the contextual style.
This is not enabled by default, if set to true the contextual style properties are removed.
Sourcepub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
B Set in the default properties of a named style to define the contextual variable for that style.
During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.
This property is part of the named styles pattern, see impl_named_style_fn! for more details.
Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if
set in the default properties of a style type.